#!/bin/sh

if [ -z "$1" ]; then
	echo Usage:
	echo "  ./getTestSources.sh buildID"
	exit 1
fi

buildID=$1

mkdir -p ${buildID}.sources
cd ${buildID}.sources
cvs -d:pserver:anonymous@dev.eclipse.org:/cvsroot/eclipse -q export -r ${buildID} org.eclipse.releng
for f in `ls org.eclipse.releng/maps/*.map`; do 
    cat $f >> ${buildID}.map;
    echo "" >> ${buildID}.map;
    echo "" >> ${buildID}.map;
done
testsMap=${buildID}-tests.map
cat ${buildID}.map | sort | uniq > ${testsMap}

#cp -p ${testsMap}{,.bak}
#echo "1. Saved as ${buildID}.sources/${testsMap}.bak"

sed -i "/^!/d" ${testsMap}
sed -i "/^#/d" ${testsMap}
sed -i "/^\*/d" ${testsMap}
sed -i "/^$/d" ${testsMap}
cp ${testsMap} junit.txt
sed -i "/org.junit/!d" junit.txt

# sdk.tests is both a feature and a plugin so we have to manually
# re-fetch the plugin later
sed -i "/plugin@org.eclipse.sdk.tests/d" ${testsMap}

#cp -p ${testsMap}{,.bak2}
#echo "2. Saved again as ${buildID}.sources/${testsMap}.bak2"

# Keep these ones by injecting "test" into their name
keep="\
org.eclipse.ant.optional.junit \
org.easymock \
org.eclipse.equinox.p2.installer \
org.eclipse.jface.examples.databinding \
"
for f in ${keep}; do
    sed -i "s/$f/$f-test/" ${testsMap}
done

#cp -p ${testsMap}{,.bak3}
#echo "3. Saved again as ${buildID}.sources/${testsMap}.bak3"

sed -i "/test/!d" ${testsMap}

#cp -p ${testsMap}{,.bak4}
#echo "4. Saved again as ${buildID}.sources/${testsMap}.bak4"

for f in ${keep}; do
    sed -i "s/${f}-test/${f}/" ${testsMap}
done

#cp -p ${testsMap}{,.bak5}
#echo "5. Saved again as ${buildID}.sources/${testsMap}.bak5"

sed -i "/win32/d" ${testsMap}
cat junit.txt | sort | uniq >> ${testsMap}
rm junit.txt

dirname=${buildID}.src
mapfile=${testsMap}

mkdir -p $dirname;
cp ${mapfile} $dirname
cd $dirname;

gawk 'BEGIN {
	FS=","
}
{

if (NF <  4) {
	split($2, method, "=");
	if (method[2] == "GET") {
	    printf("wget %s\n", $3) | "/bin/bash";
	} else {
	    split($1, version, "=");
	    split(version[1], directory, "@");
	    cvsdir=split($2, dirName, ":");
	    printf("%s %s %s%s %s %s %s %s %s %s %s\n", "cvs", "-d", ":pserver:anonymous@dev.eclipse.org:", dirName[cvsdir], "-q", "export", "-r", version[2], "-d", directory[2], directory[2]) | "/bin/bash";
	}
} 
else {
	numElements=split($1, version, "=");
	if (numElements == 1) {
	    printf("wget %s\n", $3);
	} else {
	    if (version[2] == "CVS") {
		split($2, version, "=");
		split($3, cvsloc, "=");
		cvsdir=split(cvsloc[2], dirName, ":");
		split($4, directory, "=");
		total=split(directory[2], cvsDir, "/");
		printf("%s %s %s%s %s %s %s %s %s %s %s\n", "cvs", "-d", ":pserver:anonymous@dev.eclipse.org:", dirName[cvsdir], "-q", "export", "-r", version[2], "-d", cvsDir[total], directory[2]) | "/bin/bash";
	    } else {
		total=split($4, directory, "/");
		cvsdir=split($2, dirName, ":");
		printf("%s %s %s%s %s %s %s %s %s %s %s\n", "cvs", "-d", ":pserver:anonymous@dev.eclipse.org:", dirName[cvsdir], "-q", "export", "-r", version[2], "-d", directory[total], $4) | "/bin/bash";
	    }
	}
}


}' $mapfile

# sdk.tests is both a feature and a plugin so we have to manually
# re-fetch the plugin
mv org.eclipse.sdk.tests{,-feature}
cvs -d:pserver:anonymous@dev.eclipse.org:/cvsroot/eclipse -q export -r v20060605 org.eclipse.sdk.tests
wget http://download.eclipse.org/tools/orbit/downloads/drops/S20090307012903/bundles/org.junit_3.8.2.v20090203-1005.zip
wget http://download.eclipse.org/tools/orbit/downloads/drops/S20090307012903/bundles/org.apache.ant_1.7.1.v20090120-1145.zip
unzip org.junit_*.zip
rm org.junit_*.zip
unzip org.apache.ant_*.zip
rm org.apache.ant_*.zip
tar czf ../../eclipse-tests-${buildID}-fetched-src.tar.gz *
